import sdate from '@saanaa.com/s-date';
import { subTitle, DayItem, MonthItem, Locale } from './types';

export const getSubTitles = (date: string, subTitles: subTitle[]) => {
  if (subTitles) {
    const index = subTitles.findIndex((x) => x.date === date + 'T00:00:00');
    return index >= 0 ? subTitles[index].value : null;
  }
  return null;
};

export const createArray = (start: number, end: number) => {
  return start && end ? [...Array(end - start + 1).keys()].map((num) => num + start) : [];
};

export const getMonthDetails = (
  locale: Locale,
  year: number,
  month: number,
  numberOfMonth: number,
  subTitles: subTitle[],
  todayGregorian: string
): MonthItem[] => {
  let months: MonthItem[] = [];

  for (let monthIndex = 0; monthIndex < numberOfMonth; monthIndex++) {
    if (+month + +monthIndex === 13) {
      month = 1;
      year = +year + 1;
    } else {
      month = +month + +monthIndex;
    }

    let firstDayOfMonth =
      locale === 'en'
        ? sdate.format(locale, `${year}/${month.toString().padStart(2, '0')}/01`)
        : sdate.convert('en', `${year}/${month.toString().padStart(2, '0')}/01`);

    const numberOfDays = sdate.DaysInMonth(locale, year, month);
    let days: DayItem[] = [];

    let date = firstDayOfMonth.YYYY_MM_dd;
    for (let index = 0; index < numberOfDays; index++) {
      const masterDate = sdate.format(locale, date);
      const gregorianDate = sdate.format('en', date);
      const jalaliDate = sdate.convert('fa', gregorianDate.YYYY_MM_dd);

      days.push({
        // @ts-ignore
        value: gregorianDate.YYYY_MM_dd.replaceAll('/', ''),
        gregorianDate: gregorianDate.YYYY_MM_dd,
        jalaliDate: jalaliDate.YYYY_MM_dd,
        year: masterDate.YYYY,
        month: masterDate.MM as any,
        monthName: masterDate.M,
        day: masterDate.d as any,
        weekDay: masterDate.W,
        weekDayNumber: masterDate.WW,
        isPassed: sdate.datoToNumber(date) < sdate.datoToNumber(todayGregorian),
        subTitle: getSubTitles(sdate.format('en', date, '-').YYYY_MM_dd, subTitles)
      });

      date = sdate.addDays('en', date, 1).YYYY_MM_dd;
    }

    months.push({
      year: sdate.format(locale, firstDayOfMonth.YYYY_MM_dd).YYYY,
      month: sdate.format(locale, firstDayOfMonth.YYYY_MM_dd).MM as any,
      monthName: sdate.format(locale, firstDayOfMonth.YYYY_MM_dd).M,
      days: days
    });
  }

  return months;
};
